@@ -110,7 +110,12 @@ class UserInput(dict):
             del cls._context.current
 
 
-def keynet_function(name: str) -> Callable[[F], F]:
+def keynet_function(
+    name: str,
+    *,
+    description: str,
+    base_image: Optional[str] = None,
+) -> Callable[[F], F]:
     """
     Decorator to mark a function as a Keynet serverless function.
 
@@ -123,12 +128,18 @@ def keynet_function(name: str) -> Callable[[F], F]:
 
     Args:
         name: The name of the function (required)
+        description: Description of the function's purpose (required)
+        base_image: OpenWhisk-compatible base Docker image (optional)
 
     Returns:
         The decorated function
 
     Example:
-        @keynet_function("my-serverless-function")
+        @keynet_function(
+            "my-serverless-function",
+            description="Processes images with YOLO detection",
+            base_image="openwhisk/action-python-v3.12:latest"
+        )
         def main(args):
             # Environment variables are automatically loaded from args.
             # Args can contain both env vars and function parameters:
@@ -145,6 +156,14 @@ def keynet_function(name: str) -> Callable[[F], F]:
     if not isinstance(name, str) or not name.strip():
         raise ValueError("Function name must be a non-empty string")
 
+    if not isinstance(description, str) or not description.strip():
+        raise ValueError("Function description must be a non-empty string")
+
+    if base_image is not None and (
+        not isinstance(base_image, str) or not base_image.strip()
+    ):
+        raise ValueError("Base image must be a non-empty string if provided")
+
     def decorator(func: F) -> F:
         # Validate function signature
         sig = inspect.signature(func)
@@ -203,6 +222,8 @@ def keynet_function(name: str) -> Callable[[F], F]:
         # Add metadata to the function
         wrapper._keynet_function = True  # type: ignore[attr-defined]
         wrapper._keynet_name = name  # type: ignore[attr-defined]
+        wrapper._keynet_description = description  # type: ignore[attr-defined]
+        wrapper._keynet_base_image = base_image  # type: ignore[attr-defined]
 
         return cast("F", wrapper)
 
