@@ -25,12 +25,12 @@ def valid_python_file(temp_dir: Path) -> Path:
     file_path.write_text(
         """
 # 테스트용 더미 데코레이터
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         return func
     return decorator
 
-@keynet_function("test-function")
+@keynet_function("test-function", description="Test function")
 def main(args):
     name = args.get('name', 'World')
     return {"greeting": f"Hello {name}!"}
@@ -84,9 +84,9 @@ def large_python_file(temp_dir: Path) -> Path:
     file_path = temp_dir / "large_file.py"
     # 11MB 파일 생성
     content = (
-        "def keynet_function(name):\n    def decorator(func):\n        return func\n    return decorator\n\n# "
+        "def keynet_function(name, *, description, base_image=None):\n    def decorator(func):\n        return func\n    return decorator\n\n# "
         + "x" * (11 * 1024 * 1024)
-        + "\n@keynet_function('large')\ndef main(args): pass"
+        + "\n@keynet_function('large', description='Large function')\ndef main(args): pass"
     )
     file_path.write_text(content)
     return file_path
