@@ -31,7 +31,7 @@ class TestDecoratorIntegration:
         func_file.write_text("""
 from keynet_inference.function.decorator import keynet_function
 
-@keynet_function("my-serverless-function")
+@keynet_function("my-serverless-function", description="Test my-serverless-function")
 def main(args):
     name = args.get('name', 'World')
     return {"message": f"Hello {name}!", "decorated": True}
@@ -51,7 +51,7 @@ def main(args):
         """중첩된 함수 컨텍스트 플로우"""
         execution_log = []
 
-        @keynet_function("outer-function")
+        @keynet_function("outer-function", description="Test outer-function")
         def outer_function(args):
             execution_log.append(("outer", is_inside_keynet_function()))
             result = helper_function()
@@ -62,7 +62,7 @@ def main(args):
             execution_log.append(("helper", is_inside_keynet_function()))
             return {"helper": "called"}
 
-        @keynet_function("inner-function")
+        @keynet_function("inner-function", description="Test inner-function")
         def inner_function(args):
             execution_log.append(("inner", is_inside_keynet_function()))
             return {"inner": "called"}
@@ -86,7 +86,7 @@ def main(args):
     def test_decorator_auto_env_loading(self):
         """자동 환경변수 로딩 테스트"""
 
-        @keynet_function("env-load-test-function")
+        @keynet_function("env-load-test-function", description="Test env-load-test-function")
         def main(args):
             return {
                 "env_loaded": os.environ.get("KEYNET_ENV_LOADED", "false"),
@@ -116,14 +116,14 @@ def main(args):
         results = []
         errors = []
 
-        @keynet_function("concurrent-func-1")
+        @keynet_function("concurrent-func-1", description="Test concurrent-func-1")
         def func1(args):
             import time
 
             time.sleep(0.01)  # 작은 지연
             return {"func": "1", "thread": threading.current_thread().name}
 
-        @keynet_function("concurrent-func-2")
+        @keynet_function("concurrent-func-2", description="Test concurrent-func-2")
         def func2(args):
             import time
 
@@ -161,7 +161,7 @@ def main(args):
     def test_decorator_metadata_persistence(self):
         """데코레이터 메타데이터 지속성"""
 
-        @keynet_function("metadata-test")
+        @keynet_function("metadata-test", description="Test metadata-test")
         def my_function(args):
             """Test function for metadata testing."""
             return {"test": True}
@@ -194,7 +194,7 @@ from keynet_inference.function.decorator import keynet_function
 import json
 import os
 
-@keynet_function("production-function")
+@keynet_function("production-function", description="Test production-function")
 def main(args):
     # 실제 비즈니스 로직
     action = args.get('action', 'default')
@@ -257,7 +257,7 @@ def main(args):
     def test_error_propagation_in_decorated_functions(self):
         """데코레이터 함수의 에러 전파"""
 
-        @keynet_function("error-test-function")
+        @keynet_function("error-test-function", description="Test error-test-function")
         def main(args):
             error_type = args.get("error_type", "none")
 
