@@ -11,7 +11,7 @@ class TestDecoratorValidation:
     def test_valid_main_function(self):
         """Valid main function with single args parameter"""
 
-        @keynet_function("test-function")
+        @keynet_function("test-function", description="Test test-function")
         def main(args):
             return {"result": "success"}
 
@@ -25,7 +25,7 @@ class TestDecoratorValidation:
             ValueError, match="must have exactly one parameter named 'args'"
         ):
 
-            @keynet_function("test-function")
+            @keynet_function("test-function", description="Test test-function")
             def main():
                 return {"result": "success"}
 
@@ -35,7 +35,7 @@ class TestDecoratorValidation:
             ValueError, match="must have exactly one parameter named 'args'"
         ):
 
-            @keynet_function("test-function")
+            @keynet_function("test-function", description="Test test-function")
             def main(params):
                 return {"result": "success"}
 
@@ -45,7 +45,7 @@ class TestDecoratorValidation:
             ValueError, match="must have exactly one parameter named 'args'"
         ):
 
-            @keynet_function("test-function")
+            @keynet_function("test-function", description="Test test-function")
             def main(args, extra):
                 return {"result": "success"}
 
@@ -55,7 +55,7 @@ class TestDecoratorValidation:
             ValueError, match="must have exactly one parameter named 'args'"
         ):
 
-            @keynet_function("test-function")
+            @keynet_function("test-function", description="Test test-function")
             def main(args, **kwargs):
                 return {}
 
@@ -65,7 +65,7 @@ class TestDecoratorValidation:
             ValueError, match="must have exactly one parameter named 'args'"
         ):
 
-            @keynet_function("test-function")
+            @keynet_function("test-function", description="Test test-function")
             def main(args, optional=None):
                 return {}
 
@@ -75,7 +75,7 @@ class TestDecoratorValidation:
             ValueError, match="Function name must be a non-empty string"
         ):
 
-            @keynet_function("")
+            @keynet_function("", description="Test ")
             def main(args):
                 return {}
 
@@ -85,7 +85,7 @@ class TestDecoratorValidation:
             ValueError, match="Function name must be a non-empty string"
         ):
 
-            @keynet_function("   ")
+            @keynet_function("   ", description="Test    ")
             def main(args):
                 return {}
 
@@ -95,14 +95,14 @@ class TestDecoratorValidation:
             ValueError, match="Function name must be a non-empty string"
         ):
 
-            @keynet_function(123)  # type: ignore
+            @keynet_function(123, description="Test")  # type: ignore
             def main(args):
                 return {}
 
     def test_auto_load_env(self):
         """Test that load_env is automatically called with args"""
 
-        @keynet_function("test-function")
+        @keynet_function("test-function", description="Test test-function")
         def main(args):
             return {"input": args}
 
@@ -118,7 +118,7 @@ class TestDecoratorValidation:
     def test_load_env_import_error_handling(self):
         """Test handling of load_env import errors"""
 
-        @keynet_function("test-function")
+        @keynet_function("test-function", description="Test test-function")
         def main(args):
             return {"input": args}
 
@@ -140,7 +140,7 @@ class TestDecoratorValidation:
     def test_load_env_execution_error(self):
         """Test handling of load_env execution errors"""
 
-        @keynet_function("test-function")
+        @keynet_function("test-function", description="Test test-function")
         def main(args):
             return {"input": args}
 
