@@ -45,13 +45,13 @@ class TestSecurityFeatures:
 import time
 
 # 실제 데코레이터 대신 더미 데코레이터 사용
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         func._keynet_name = name
         return func
     return decorator
 
-@keynet_function("slow")
+@keynet_function("slow", description="Test slow")
 def main(args):
     # 3초 대기 (2초 타임아웃 초과)
     time.sleep(3)
@@ -124,13 +124,13 @@ import os
 import subprocess
 
 # 실제 데코레이터 대신 더미 데코레이터 사용
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         func._keynet_name = name
         return func
     return decorator
 
-@keynet_function("injection")
+@keynet_function("injection", description="Test injection")
 def main(args):
     # 시스템 명령 실행 시도 (간단한 명령)
     try:
@@ -162,13 +162,13 @@ def main(args):
 import urllib.request
 
 # 실제 데코레이터 대신 더미 데코레이터 사용
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         func._keynet_name = name
         return func
     return decorator
 
-@keynet_function("network")
+@keynet_function("network", description="Test network")
 def main(args):
     try:
         response = urllib.request.urlopen('http://example.com')
@@ -196,13 +196,13 @@ def main(args):
         dangerous_file.write_text(
             """
 # 실제 데코레이터 대신 더미 데코레이터 사용
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         func._keynet_name = name
         return func
     return decorator
 
-@keynet_function("dangerous")
+@keynet_function("dangerous", description="Test dangerous")
 def main(args):
     imports = []
     try:
@@ -260,13 +260,13 @@ def main(args):
         error_file.write_text(
             """
 # 실제 데코레이터 대신 더미 데코레이터 사용
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         func._keynet_name = name
         return func
     return decorator
 
-@keynet_function("error_test")
+@keynet_function("error_test", description="Test error_test")
 def main(args):
     # 민감한 정보가 포함된 에러 발생
     password = "secret123"
@@ -292,13 +292,13 @@ def main(args):
         cpu_hog.write_text(
             """
 # 실제 데코레이터 대신 더미 데코레이터 사용
-def keynet_function(name):
+def keynet_function(name, *, description, base_image=None):
     def decorator(func):
         func._keynet_name = name
         return func
     return decorator
 
-@keynet_function("cpu_test")
+@keynet_function("cpu_test", description="Test cpu_test")
 def main(args):
     # 무한 계산 (타임아웃까지 계속)
     result = 0
